@@ -31,6 +31,9 @@
 # define __END_DECLS /* empty */
 #endif
 
+#define LUA_INDEX_CONVENTION
+/* #define USE_SEPARATE_NAMESPACE */
+
 #ifdef WIN32
 #undef bool
 typedef int bool;
